From 645e752c5a84baeb21015cdc85fc05b7d16312c8 Mon Sep 17 00:00:00 2001
From: hc <hc@nodka.com>
Date: Sat, 11 May 2024 01:13:52 +0000
Subject: [PATCH] disable i2c1

---
 kernel/drivers/tee/amdtee/amdtee_if.h |   10 ++++++----
 1 files changed, 6 insertions(+), 4 deletions(-)

diff --git a/kernel/drivers/tee/amdtee/amdtee_if.h b/kernel/drivers/tee/amdtee/amdtee_if.h
index ff48c3e..e2014e2 100644
--- a/kernel/drivers/tee/amdtee/amdtee_if.h
+++ b/kernel/drivers/tee/amdtee/amdtee_if.h
@@ -118,16 +118,18 @@
 
 /**
  * struct tee_cmd_load_ta - load Trusted Application (TA) binary into TEE
  * @low_addr:    [in] bits [31:0] of the physical address of the TA binary
  * @hi_addr:     [in] bits [63:32] of the physical address of the TA binary
  * @size:        [in] size of TA binary in bytes
  * @ta_handle:   [out] return handle of the loaded TA
  */
 struct tee_cmd_load_ta {
 	u32 low_addr;
 	u32 hi_addr;
 	u32 size;
 	u32 ta_handle;
+	u32 return_origin;
 };
 
 /**
@@ -118,16 +118,18 @@
 /**
  * struct tee_cmd_load_ta - load Trusted Application (TA) binary into TEE
- * @low_addr:    [in] bits [31:0] of the physical address of the TA binary
- * @hi_addr:     [in] bits [63:32] of the physical address of the TA binary
- * @size:        [in] size of TA binary in bytes
- * @ta_handle:   [out] return handle of the loaded TA
+ * @low_addr:       [in] bits [31:0] of the physical address of the TA binary
+ * @hi_addr:        [in] bits [63:32] of the physical address of the TA binary
+ * @size:           [in] size of TA binary in bytes
+ * @ta_handle:      [out] return handle of the loaded TA
+ * @return_origin:  [out] origin of return code after TEE processing
  */
 struct tee_cmd_load_ta {

--
Gitblit v1.6.2